## Changelog

### 1.0.1 - 2017-02-02

*   [resultsdb_conventions-1.0.1.tar.xz](https://releases.pagure.org/fedora-qa/resultsdb_conventions/resultsdb_conventions-1.0.1.tar.xz)

1.  Pass through what the API result submission function returns

### 1.0.0 - 2017-02-02

*   [resultsdb_conventions-1.0.0.tar.xz](https://releases.pagure.org/fedora-qa/resultsdb_conventions/resultsdb_conventions-1.0.0.tar.xz)

1.  Initial release of resultsdb_conventions
